@@ -520,7 +520,10 @@ def test_str_input():
         "-3.1e10": (-3.1e10, 0.1e10),
         "169.0(7)": (169, 0.7),
         "-0.1+/-1": (-0.1, 1),
-        "-13e-2+/-1e2": (-13e-2, 1e2)
+        "-13e-2+/-1e2": (-13e-2, 1e2),
+        '-14.(15)': (-14, 15),
+        '-100.0(15)': (-100, 1.5),
+        '14.(15)': (14, 15)
         }
           
     for (representation, values) in tests.iteritems():
